"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const minimatch_1 = __importDefault(require("minimatch"));
const glob = jest.requireActual("glob");
let mockFiles = null;
function setMockFiles(files) {
    mockFiles = files;
}
function resetMock() {
    mockFiles = null;
}
const originalSync = glob.sync;
function syncMock(pattern, options = {}) {
    if (!mockFiles) {
        return originalSync(pattern, options);
    }
    /* slice the cwd away since it is prepended automatically and makes it harder
     * to test with */
    const cwd = options.cwd || "";
    const dir = cwd.replace(process.cwd(), "").replace(/^\/(.*)/, "$1/");
    let src = mockFiles;
    if (dir) {
        src = src
            .filter(cur => cur.startsWith(dir))
            .map(cur => cur.slice(dir.length));
    }
    return src.filter(cur => minimatch_1.default(cur, pattern));
}
glob.setMockFiles = setMockFiles;
glob.resetMock = resetMock;
glob.sync = syncMock;
module.exports = glob;
